==> modx-2.1.0-pl-ja.zip: modx-2.1.0-pl-ja/core/lexicon/ja/formcustomization.inc.php <==
<?php
/**
 * Form Customization Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['action'] = '操作内容';
$_lang['action_desc'] = 'このルールはアクションに適用されます。';
$_lang['activate'] = '有効化';
$_lang['constraint'] = '条件';
$_lang['constraint_class'] = 'このルールの対象';
$_lang['constraint_class_desc'] = 'オプション。「テンプレートIDが4の場合にこのルールを有効にする」などの条件をここでセットします。投稿画面の場合「modResource」でよいみたいです(※注・日本チーム) Optional. If set, along with the Constraint Field and Constraint options, will restrict this rule to the constraints applied.';
$_lang['constraint_desc'] = 'オプション。有効条件と見なす値をセットします。たとえば「テンプレートIDが4の場合にこのルールを有効にする」の場合「4」をここにセットします。Optional. The value of the Constraint Field that should be checked against.';
$_lang['constraint_field'] = 'フィールド名';
$_lang['constraint_field_desc'] = 'オプション。対象フィールドの名前を記述します。たとえば「template」など。Optional. The field by which this constraint should be applied.';
$_lang['containing_panel'] = 'これを含む領域';
$_lang['containing_panel_desc'] = '対象オブジェクト(フィールドやタブ)を含むDIV領域のID名。modx-panel-resource・modx-page-settings・modx-resource-tabsのうちのいずれか。This is sometimes necessary for certain rules, so that the system can know what form or panel the field is in.';
$_lang['deactivate'] = '無効化';
$_lang['default_value'] = 'デフォルト値';
$_lang['export'] = 'エクスポート';
$_lang['field'] = 'フィールド';
$_lang['field_desc'] = 'This is the field to affect. This may also be a tab, or TV. If it is a TV, please specify in this format: "tv#", where # is the ID of the TV.';
$_lang['field_default'] = 'フィールドのデフォルト値';
$_lang['field_label'] = 'フィールドのラベル';
$_lang['field_visible'] = 'フィールドの表示／非表示';
$_lang['fields'] = 'フィールド';
$_lang['file'] = 'ファイル';
$_lang['filter_by_action'] = 'Filter by Action...';
$_lang['filter_by_rule_type'] = 'Filter by Rule...';
$_lang['filter_by_search'] = 'Search...';
$_lang['for_parent'] = 'For Parent';
$_lang['for_parent_desc'] = 'このルールを親リソースに適用させたい場合はチェックしてください。Only use with Resources or objects with a `parent` field. Useful for the "create" page of Resources.';
$_lang['form_customization_msg'] = '現在適用されているカスタマイズルールの一覧です。フォームのカスタマイズルールに関する詳しい情報については<a href="http://rtfm.modx.com/display/revolution20/Customizing+the+Manager" target="_blank">こちら</a>を参照してください。 Please note that improper Rules might cause problems with your MODX Revolution installation. Inactive Rules are faded gray.';
$_lang['form_rules'] = 'フォームのルール';
$_lang['import'] = 'import';
$_lang['import_from_xml'] = 'XMLファイルからセットをインポート';
$_lang['label'] = 'Label';
$_lang['original_value'] = 'Original Value';
$_lang['profile'] = 'プロファイル';
$_lang['profile_create'] = 'プロファイル新規作成';
$_lang['profile_err_nfs'] = 'Form Customization Profile not found with ID [[+id]].';
$_lang['profile_err_ns'] = 'Form Customization Profile not specified!';
$_lang['profile_err_remove'] = 'An error occurred while trying to remove the Profile.';
$_lang['profile_err_save'] = 'An error occurred while trying to save the Profile.';
$_lang['profile_msg'] = 'Here you can specify Sets for this Profile. A Set is a collection of Rules that apply for a given page (Update or Create Resource). They can also be restricted to certain Templates, or other field values on the Resource. Constraints for the Create Resource Sets will execute based on the parent of the newly created Resource&apos;s value.';
$_lang['profile_new'] = '新しいプロファイル';
$_lang['profile_remove'] = 'プロファイルを削除';
$_lang['profile_remove_confirm'] = 'Are you sure you want to completely remove this Profile? This is irreversible.';
$_lang['profile_remove_multiple'] = 'Remove Multiple Profiles';
$_lang['profile_remove_multiple_confirm'] = 'Are you sure you want to completely remove these Profiles? This is irreversible.';
$_lang['profile_usergroup_err_ae'] = 'That User Group is already assigned to this Profile!';
$_lang['profile_usergroups_msg'] = 'Here you can assign the User Groups that will use this Profile. If no User Groups are assigned, all Users will use this Profile.';
$_lang['profiles'] = 'フォームカスタマイズプロファイル';
$_lang['profiles_msg'] = 'This is a list of your Form Customization Profiles. Profiles can contain many Form Customization Rules, and can be activated or deactivated. They can also be configured to only apply to certain User Groups.';
$_lang['rank'] = 'Rank';
$_lang['rank_desc'] = 'The order the Rule is executed in. A lower number means that it will be executed earlier.';
$_lang['rule'] = 'ルール';
$_lang['rule_create'] = 'ルールを作成';
$_lang['rule_desc'] = 'このフィールドに適用されるルールの種類';
$_lang['rule_description_desc'] = 'オプション。ルールの詳細';
$_lang['rule_err_ae'] = 'そのフィールドにはすでにルールが設定されています';
$_lang['rule_err_duplicate'] = 'ルールの複製中にエラーが発生しました。';
$_lang['rule_err_nf'] = 'ルールが見つかりません。';
$_lang['rule_err_ns'] = 'ルールが指定されていません。';
$_lang['rule_err_remove'] = 'ルールの削除中にエラーが発生しました。';
$_lang['rule_err_save'] = 'ルールの保存中にエラーが発生しました。';
$_lang['rule_remove'] = 'ルールを削除';
$_lang['rule_remove_confirm'] = '本当にこのルールを削除しますか？';
$_lang['rule_remove_multiple'] = '複数のルールを削除';
$_lang['rule_remove_multiple_confirm'] = '本当にこれらのルールを削除しますか？元には戻せません。';
$_lang['rule_update'] = 'ルールを編集';
$_lang['rule_value_desc'] = 'ルールに値を設定します。';
$_lang['rules'] = 'ルール';
$_lang['set'] = 'Set';
$_lang['set_and_fields'] = 'Set Information and Fields';
$_lang['set_change_template'] = 'Change Template For Set';
$_lang['set_change_template_confirm'] = 'Are you sure you want to do this? This will change the Template that these Rules apply to. If so, MODX will first save your changes before reloading the page to refresh the new TVs for the new Template.';
$_lang['set_constraint_field_desc'] = 'Setting the Constraint field will prevent the rules in this Set from executing unless the field for this Resource matches the "constraint" value.';
$_lang['set_constraint_desc'] = 'Set the value of the field (specified above) to restrict the rules in this Set from being executed unless the Resource has this value on the specified constraint field.';
$_lang['set_create'] = 'セットを新規作成';
$_lang['set_err_nfs'] = 'No Set found with ID [[+id]]';
$_lang['set_err_ns'] = 'No Set specified.';
$_lang['set_fields_msg'] = 'Here you can adjust the fields for this page, including their visibility, labels and default values. Just double-click on a row to edit its value. Leave a field empty to use the default setting.';
$_lang['set_import_err_upload'] = 'An error occurred while trying to find the XML file. Please specify a valid file.';
$_lang['set_import_err_xml'] = 'An error occurred importing the XML file. Please ensure you specified a valid Form Customization Set XML File.';
$_lang['set_import_msg'] = 'Select an XML file to import a Form Customization Set from. It must be in the correct XML Form Customization format.';
$_lang['set_msg'] = 'Here you can edit what fields, tabs and Template Variables show for this page, as well as their labels and default values. Just double-click on a column to edit its value. You can also use the tab key to progress through the grid. Leave a field blank to use the default setting.';
$_lang['set_new'] = 'セットを新規作成';
$_lang['set_remove'] = 'Remove Set';
$_lang['set_remove_confirm'] = 'Are you sure you want to permanently remove this set? This is irreversable.';
$_lang['set_remove_multiple'] = 'Remove Multiple Sets';
$_lang['set_remove_multiple_confirm'] = 'Are you sure you want to permanently remove these sets? This is irreversable.';
$_lang['set_tab_err_ae'] = 'A tab already exists with that ID. Please specify another.';
$_lang['set_tabs_msg'] = 'Here you adjust the tabs for this page, including their visibility and title. Just double-click on a row to edit its value. Leave a field empty to use the default setting.';
$_lang['set_template_desc'] = 'Choosing a Template will limit the rules in the Set from executing unless the Resource has the specified Template.';
$_lang['set_tvs_msg'] = 'Here you can set visibility, labels, default values and the tabs they reside in by double-clicking on the row in the grid. Note: If you move a TV to another tab, you can adjust the order of the TV in the "Tab Rank" field. Leave a field empty to use the default setting.';
$_lang['sets'] = 'Form Customization Sets';
$_lang['simplexml_err_nf'] = 'MODX requires the SimpleXML PHP extension to use this feature. Please ensure the extension is installed before continuing.';
$_lang['tab'] = 'タブ';
$_lang['tab_create'] = '新しいタブを作成';
$_lang['tab_id'] = 'ID';
$_lang['tab_name'] = 'Tab Name';
$_lang['tab_title'] = 'タブのタイトル';
$_lang['tab_new'] = '新しいタブ';
$_lang['tab_rank'] = 'タブの順序';
$_lang['tab_remove'] = 'タブを外す';
$_lang['tab_remove_confirm'] = 'Are you sure you want to remove this tab?';
$_lang['tab_visible'] = 'タブの表示／非表示';
$_lang['tabs'] = 'タブ';
$_lang['tv'] = 'テンプレート変数';
$_lang['tv_default'] = '既定値';
$_lang['tv_label'] = 'テンプレート変数のラベル';
$_lang['tv_name'] = 'Name';
$_lang['tv_move'] = 'テンプレート変数をタブに移動';
$_lang['tv_visible'] = 'テンプレート変数の表示／非表示';
$_lang['tvs'] = 'テンプレート変数';
$_lang['usergroup'] = 'ユーザーグループ';
$_lang['usergroup_create'] = 'ユーザーグループを追加';
$_lang['usergroup_desc'] = 'オプション。設定すると、このルールをユーザーグループで指定されたユーザーのみに制限します。';
$_lang['usergroup_remove'] = 'プロファイルからユーザーグループを削除';
$_lang['usergroup_remove_confirm'] = 'Are you sure you want this Profile to no longer apply to Users in this User Group?';
$_lang['usergroups'] = 'ユーザーグループ';
$_lang['visible'] = 'Visible';
$_lang['xmlwriter_err_nf'] = 'MODX requires the XMLWriter PHP extension to use this feature. Please ensure the extension is installed before continuing.';

==> modx-2.1.5-pl-ja.zip: modx-2.1.5-pl-ja/core/lexicon/ja/formcustomization.inc.php <==
<?php
/**
 * Form Customization Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['action'] = '操作内容';
$_lang['action_desc'] = 'このルールはアクションに適用されます。';
$_lang['activate'] = '有効化';
$_lang['constraint'] = '条件';
$_lang['constraint_class'] = 'このルールの対象';
$_lang['constraint_class_desc'] = 'オプション。「テンプレートIDが4の場合にこのルールを有効にする」などの条件をここでセットします。投稿画面の場合「modResource」でよいみたいです(※注・日本チーム) Optional. If set, along with the Constraint Field and Constraint options, will restrict this rule to the constraints applied.';
$_lang['constraint_desc'] = 'オプション。有効条件と見なす値をセットします。たとえば「テンプレートIDが4の場合にこのルールを有効にする」の場合「4」をここにセットします。Optional. The value of the Constraint Field that should be checked against.';
$_lang['constraint_field'] = 'constraint_field';
$_lang['constraint_field_desc'] = 'オプション。対象フィールドの名前を記述します。たとえば「template」など。Optional. The field by which this constraint should be applied.';
$_lang['containing_panel'] = 'これを含む領域';
$_lang['containing_panel_desc'] = '対象オブジェクト(フィールドやタブ)を含むDIV領域のID名。modx-panel-resource・modx-page-settings・modx-resource-tabsのうちのいずれか。This is sometimes necessary for certain rules, so that the system can know what form or panel the field is in.';
$_lang['deactivate'] = '無効化';
$_lang['default_value'] = 'デフォルト値';
$_lang['export'] = 'エクスポート';
$_lang['field'] = 'フィールド';
$_lang['field_desc'] = 'This is the field to affect. This may also be a tab, or TV. If it is a TV, please specify in this format: "tv#", where # is the ID of the TV.';
$_lang['field_default'] = 'フィールドのデフォルト値';
$_lang['field_label'] = 'フィールドのラベル';
$_lang['field_visible'] = 'フィールドの表示／非表示';
$_lang['fields'] = 'フィールド';
$_lang['file'] = 'ファイル';
$_lang['filter_by_action'] = 'Filter by Action...';
$_lang['filter_by_rule_type'] = 'Filter by Rule...';
$_lang['filter_by_search'] = 'Search...';
$_lang['for_parent'] = 'For Parent';
$_lang['for_parent_desc'] = 'このルールを親リソースに適用させたい場合はチェックしてください。Only use with Resources or objects with a `parent` field. Useful for the "create" page of Resources.';
$_lang['form_customization_msg'] = '利用可能なカスタマイズルールの一覧です。Please note that improper Rules might cause problems with your MODX Revolution installation. Inactive Rules are faded gray.';
$_lang['form_rules'] = 'フォームのルール';
$_lang['import'] = 'import';
$_lang['import_from_xml'] = 'XMLファイルからセットをインポート';
$_lang['label'] = 'ラベル';
$_lang['original_value'] = 'オリジナル値';
$_lang['profile'] = 'プロファイル';
$_lang['profile_create'] = 'プロファイル新規作成';
$_lang['profile_err_nfs'] = 'Form Customization Profile not found with ID [[+id]].';
$_lang['profile_err_ns'] = 'Form Customization Profile not specified!';
$_lang['profile_err_remove'] = 'An error occurred while trying to remove the Profile.';
$_lang['profile_err_save'] = 'An error occurred while trying to save the Profile.';
$_lang['profile_msg'] = 'Here you can specify Sets for this Profile. A Set is a collection of Rules that apply for a given page (Update or Create Resource). They can also be restricted to certain Templates, or other field values on the Resource. Constraints for the Create Resource Sets will execute based on the parent of the newly created Resource&apos;s value.';
$_lang['profile_new'] = '新しいプロファイル';
$_lang['profile_remove'] = 'プロファイルを削除';
$_lang['profile_remove_confirm'] = 'Are you sure you want to completely remove this Profile? This is irreversible.';
$_lang['profile_remove_multiple'] = 'Remove Multiple Profiles';
$_lang['profile_remove_multiple_confirm'] = 'Are you sure you want to completely remove these Profiles? This is irreversible.';
$_lang['profile_usergroup_err_ae'] = 'That User Group is already assigned to this Profile!';
$_lang['profile_usergroups_msg'] = 'Here you can assign the User Groups that will use this Profile. If no User Groups are assigned, all Users will use this Profile.';
$_lang['profiles'] = 'フォームカスタマイズプロファイル';
$_lang['profiles_msg'] = 'This is a list of your Form Customization Profiles. Profiles can contain many Form Customization Rules, and can be activated or deactivated. They can also be configured to only apply to certain User Groups.';
$_lang['rank'] = 'ランク';
$_lang['rank_desc'] = 'The order the Rule is executed in. A lower number means that it will be executed earlier.';
$_lang['rule'] = 'ルール';
$_lang['rule_create'] = 'ルールを作成';
$_lang['rule_desc'] = 'このフィールドに適用されるルールの種類';
$_lang['rule_description_desc'] = 'オプション。ルールの詳細';
$_lang['rule_err_ae'] = 'そのフィールドにはすでにルールが設定されています';
$_lang['rule_err_duplicate'] = 'ルールの複製中にエラーが発生しました。';
$_lang['rule_err_nf'] = 'ルールが見つかりません。';
$_lang['rule_err_ns'] = 'ルールが指定されていません。';
$_lang['rule_err_remove'] = 'ルールの削除中にエラーが発生しました。';
$_lang['rule_err_save'] = 'ルールの保存中にエラーが発生しました。';
$_lang['rule_remove'] = 'ルールを削除';
$_lang['rule_remove_confirm'] = '本当にこのルールを削除しますか？';
$_lang['rule_remove_multiple'] = '複数のルールを削除';
$_lang['rule_remove_multiple_confirm'] = '本当にこれらのルールを削除しますか？元には戻せません。';
$_lang['rule_update'] = 'ルールを編集';
$_lang['rule_value_desc'] = 'ルールに値を設定します。';
$_lang['rules'] = 'ルール';
$_lang['set'] = 'Set';
$_lang['set_and_fields'] = '基本設定とフィールド構成';
$_lang['set_change_template'] = 'Change Template For Set';
$_lang['set_change_template_confirm'] = 'Are you sure you want to do this? This will change the Template that these Rules apply to. If so, MODX will first save your changes before reloading the page to refresh the new TVs for the new Template.';
$_lang['set_constraint_field_desc'] = 'Setting the Constraint field will prevent the rules in this Set from executing unless the field for this Resource matches the "constraint" value.';
$_lang['set_constraint_desc'] = 'Set the value of the field (specified above) to restrict the rules in this Set from being executed unless the Resource has this value on the specified constraint field.';
$_lang['set_create'] = 'セットを新規作成';
$_lang['set_err_nfs'] = 'No Set found with ID [[+id]]';
$_lang['set_err_ns'] = 'No Set specified.';
$_lang['set_fields_msg'] = 'Here you can adjust the fields for this page, including their visibility, labels and default values. Just double-click on a row to edit its value. Leave a field empty to use the default setting.';
$_lang['set_import_err_upload'] = 'An error occurred while trying to find the XML file. Please specify a valid file.';
$_lang['set_import_err_xml'] = 'An error occurred importing the XML file. Please ensure you specified a valid Form Customization Set XML File.';
$_lang['set_import_msg'] = 'Select an XML file to import a Form Customization Set from. It must be in the correct XML Form Customization format.';
$_lang['set_msg'] = '投稿画面のフィールド構成・タブ構成・デフォルト値などをカスタマイズできます。各部をシングルクリックまたはダブルクリックすると値を編集できます。';
$_lang['set_new'] = 'セットを新規作成';
$_lang['set_remove'] = 'Remove Set';
$_lang['set_remove_confirm'] = 'Are you sure you want to permanently remove this set? This is irreversable.';
$_lang['set_remove_multiple'] = 'Remove Multiple Sets';
$_lang['set_remove_multiple_confirm'] = 'Are you sure you want to permanently remove these sets? This is irreversable.';
$_lang['set_tab_err_ae'] = 'A tab already exists with that ID. Please specify another.';
$_lang['set_tabs_msg'] = 'Here you adjust the tabs for this page, including their visibility and title. Just double-click on a row to edit its value. Leave a field empty to use the default setting.';
$_lang['set_template_desc'] = 'Choosing a Template will limit the rules in the Set from executing unless the Resource has the specified Template.';
$_lang['set_tvs_msg'] = 'Here you can set visibility, labels, default values and the tabs they reside in by double-clicking on the row in the grid. Note: If you move a TV to another tab, you can adjust the order of the TV in the "Tab Rank" field. Leave a field empty to use the default setting.';
$_lang['sets'] = 'Form Customization Sets';
$_lang['simplexml_err_nf'] = 'MODX requires the SimpleXML PHP extension to use this feature. Please ensure the extension is installed before continuing.';
$_lang['tab'] = 'タブ';
$_lang['tab_create'] = '新しいタブを作成';
$_lang['tab_id'] = 'ID';
$_lang['tab_name'] = 'Tab Name';
$_lang['tab_title'] = 'タブのタイトル';
$_lang['tab_new'] = '新しいタブ';
$_lang['tab_rank'] = 'タブの順序';
$_lang['tab_remove'] = 'タブを外す';
$_lang['tab_remove_confirm'] = 'このタブを削除します。';
$_lang['tab_visible'] = 'タブの表示／非表示';
$_lang['tabs'] = 'タブの構成';
$_lang['tv'] = 'テンプレート変数';
$_lang['tv_default'] = '既定値';
$_lang['tv_label'] = 'テンプレート変数のラベル';
$_lang['tv_name'] = 'Name';
$_lang['tv_move'] = 'テンプレート変数をタブに移動';
$_lang['tv_visible'] = 'テンプレート変数の表示／非表示';
$_lang['tvs'] = 'テンプレート変数';
$_lang['usergroup'] = 'ユーザーグループ';
$_lang['usergroup_create'] = 'ユーザーグループを追加';
$_lang['usergroup_desc'] = 'オプション。設定すると、このルールをユーザーグループで指定されたユーザーのみに制限します。';
$_lang['usergroup_remove'] = 'プロファイルからユーザーグループを削除';
$_lang['usergroup_remove_confirm'] = 'Are you sure you want this Profile to no longer apply to Users in this User Group?';
$_lang['usergroups'] = 'ユーザーグループ';
$_lang['visible'] = '表示する';
$_lang['xmlwriter_err_nf'] = 'MODX requires the XMLWriter PHP extension to use this feature. Please ensure the extension is installed before continuing.';
